translate.convert.po2php

Package translate :: Package convert :: Module po2php |
[hide private]
[frames] | no frames]

# Module po2php

source code

convert Gettext PO localization files to PHP localization files

see: http://translate.sourceforge.net/wiki/toolkit/po2php for examples and usage instructions

Classes | [hide private]
| rephp

Functions | [hide private]
convertphp(inputfile, outputfile, templatefile, includefuzzy=False) | source code
main(argv=None) | source code

Variables | [hide private]
| eol = `"\n"`

Imports: quote, po, php